diff -urN mkinitrd/init mkinitrd-dmraid/init
--- mkinitrd/init	2009-04-03 04:13:59.000000000 +0600
+++ mkinitrd-dmraid/init	2009-09-06 19:25:08.000000000 +0600
@@ -76,6 +76,9 @@
     rootfs=*)
       ROOTFS=`echo $ARG | cut -f2 -d=`
     ;;
+    rootfstype=*)
+      ROOTFS=`echo $ARG | cut -f2 -d=`
+    ;;
     luksdev=/dev/*)
       LUKSDEV=`echo $ARG | cut -f2 -d=`
     ;;
@@ -137,6 +140,11 @@
     /sbin/mdadm -A -s
   fi
   
+  # Initialize ATARAID:
+  if [ -x /sbin/dmraid ]; then
+    /sbin/dmraid -ay
+  fi
+  
   # Find root device if a label was given:
   if echo $ROOTDEV | grep -q "LABEL=" ; then
     ROOTDEV=`findfs $ROOTDEV`
diff -urN mkinitrd/mkinitrd mkinitrd-dmraid/mkinitrd
--- mkinitrd/mkinitrd	2009-08-14 01:41:32.000000000 +0600
+++ mkinitrd-dmraid/mkinitrd	2009-09-06 16:58:02.000000000 +0600
@@ -38,8 +38,10 @@
 # custom "install" lines and causing /sbin/modprobe to be copied to the
 # initrd (thanks to Ken Milmore).
 # Of course, license terms remain unchanged.
+# Modified by Rytchkov Alexey <lilo0@nm.ru> September 2009
+# to add support for ATARAID partitions (static dmraid binary is required)
 
-MKINITRD_VERSION=1.3.4
+MKINITRD_VERSION=1.3.4a
 
 print_usage() {
   cat << EOF
@@ -87,6 +89,7 @@
             /dev/vg/root
   -L      Add support for LVM partitions
   -R      Add support for RAID partitions
+  -D      Add support for ATARAID partitions
   -V      Display version number
 
 A simple example:  Build an initrd for a reiserfs root partition:
@@ -281,6 +284,10 @@
       RAID=1
       shift
       ;;
+    -D)
+      DMRAID=1
+      shift
+      ;;
     *) # unknown, prevent infinite loop
       shift
       ;;
@@ -364,6 +371,17 @@
   fi
 fi
 
+# Include ATARAID support in initrd
+if [ ! -z "$DMRAID" ]; then
+  if [ -r /sbin/dmraid ]; then
+    mkdir -p $SOURCE_TREE/sbin
+    cp /sbin/dmraid $SOURCE_TREE/sbin/dmraid
+    chmod 755 $SOURCE_TREE/sbin/dmraid
+  else
+    echo "ERROR:  dmraid binary is missing, ATARAID support not installed"
+  fi
+fi
+
 # Include LVM support in initrd
 if [ ! -z "$LVM" ]; then
   if [ -f /sbin/lvm.static ]; then
diff -urN mkinitrd/mkinitrd.8 mkinitrd-dmraid/mkinitrd.8
--- mkinitrd/mkinitrd.8	2008-04-20 11:17:21.000000000 +0600
+++ mkinitrd-dmraid/mkinitrd.8	2009-09-06 17:31:01.000000000 +0600
@@ -49,6 +49,9 @@
 .B \-R
 ]
 [
+.B \-D
+]
+[
 .B \-V
 ]
 .SH DESCRIPTION
@@ -149,6 +152,10 @@
 This option adds RAID support to the initrd, if a static mdadm binary is
 available on the system.
 .TP
+.B \-D
+This option adds ATARAID support to the initrd, if a static dmraid binary is
+available on the system.
+.TP
 .B \-V
 Display version information and exit.
 .SH EXAMPLES
diff -urN mkinitrd/mkinitrd.SlackBuild mkinitrd-dmraid/mkinitrd.SlackBuild
--- mkinitrd/mkinitrd.SlackBuild	2009-08-14 01:44:49.000000000 +0600
+++ mkinitrd-dmraid/mkinitrd.SlackBuild	2009-09-06 19:02:12.000000000 +0600
@@ -21,7 +21,7 @@
 #  ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
-VERSION=1.3.4
+VERSION=1.3.4a
 BB=1.12.1
 ARCH=${ARCH:-i486}
 NUMJOBS=${NUMJOBS:--j7}
diff -urN mkinitrd/mkinitrd.conf.5 mkinitrd-dmraid/mkinitrd.conf.5
--- mkinitrd/mkinitrd.conf.5	2008-12-19 18:11:07.000000000 +0500
+++ mkinitrd-dmraid/mkinitrd.conf.5	2009-09-06 17:32:27.000000000 +0600
@@ -134,6 +134,16 @@
 RAID="1"          # Add RAID support to initrd
 
 .TP 5
+.I DMRAID
+This option adds the dmraid binary to the initrd to support ATARAID.
+.br
+Examples:
+.br
+DMRAID="0"          # Do not add ATARAID support to initrd
+.br
+DMRAID="1"          # Add ATARAID support to initrd
+
+.TP 5
 .I LVM
 This option adds support for LVM partitions into the initrd.
 If you wish to add LVM support to the initrd, then set this to 1;
diff -urN mkinitrd/mkinitrd.conf.sample mkinitrd-dmraid/mkinitrd.conf.sample
--- mkinitrd/mkinitrd.conf.sample	2008-04-04 05:06:59.000000000 +0600
+++ mkinitrd-dmraid/mkinitrd.conf.sample	2009-09-06 16:50:28.000000000 +0600
@@ -12,5 +12,6 @@
 #ROOTFS="ext3"
 #RESUMEDEV="/dev/hda2"
 #RAID="0"
+#DMRAID="0"
 #LVM="0"
 #WAIT="1"
